<?php
/**
 * Custom filter, hooks and functions to support WooCommerce
 *
 * @package    SuperNews
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

global $woo_options;

// Indicate that this theme support WooCommerce.
add_theme_support( 'woocommerce' );

// Remove WooCommerce default styles.
add_filter( 'woocommerce_enqueue_styles', '__return_false' );

// Remove breadcrumbs.
remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );

// Remove rating on product page.
remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 );

/**
 * Archive layout.
 *
 * @since  1.0.0
 */
function supernews_woo_layout( $layout ) {

	$option = of_get_option( 'supernews_woo_archive_layout', 'fullwidth' );

	if ( is_shop() ) {
		if ( 'fullwidth' === $option ) {
			$layout = '1c';
		} elseif ( 'sidebar' === $option ) {
			$layout = 'narrow';
		}
	}

	return $layout;

}
add_filter( 'theme_mod_theme_layout', 'supernews_woo_layout', 15 );

/**
 * WooCommerce page layout.
 *
 * @since  1.0.0
 */
function supernews_woo_pages_layout( $theme_layout ) {

	if ( is_product() || is_cart() || is_checkout() || is_account_page() ) {

		$layout = get_post_layout( get_queried_object_id() );
		$args   = theme_layouts_get_args();

		// Set the default product page to fullwidth layout.
		$args['default'] = '1c';
		$theme_layout    = $args['default'];

		if ( 'default' !== $layout ) {
			$theme_layout = $layout;
		}

	}

	return $theme_layout;

}
add_filter( 'theme_mod_theme_layout', 'supernews_woo_pages_layout', 15 );

/**
 * Define image sizes on theme activation.
 *
 * @since  1.0.0
 */
function supernews_woocommerce_image_sizes() {

	global $pagenow;

	if ( is_admin() && isset( $_GET['activated'] ) && $pagenow == 'themes.php' ) {

		$catalog = array(
			'width'  => '236',
			'height' => '236',
			'crop'   => 1
		);

		$single = array(
			'width'  => '514',
			'height' => '514',
			'crop'   => 1
		);

		$thumbnail = array(
			'width'  => '127',
			'height' => '127',
			'crop'   => 1
		);

		// Product thumbnail size.
		update_option( 'shop_catalog_image_size', $catalog );

		// Single product image size.
		update_option( 'shop_single_image_size', $single );

		// Image gallery thumbnail size.
		update_option( 'shop_thumbnail_image_size', $thumbnail );

	}

}
add_action( 'init', 'supernews_woocommerce_image_sizes', 1 );

if ( ! function_exists( 'supernews_header_cart' ) ) :
/**
 * Header Cart
 *
 * @since  1.1.0
 */
function supernews_header_cart() {
	?>
	<div class="header-cart">
		<ul class="sf-menu">
			<li>
				<a class="cart-contents" href="<?php echo esc_url( WC()->cart->get_cart_url() ); ?>"><i class="fa fa-shopping-cart"></i><?php echo sprintf( _n( '%d item', '%d items', WC()->cart->get_cart_contents_count(), 'supernews'), (int) WC()->cart->get_cart_contents_count() ); ?> - <?php echo wp_kses_data( WC()->cart->get_cart_subtotal() ); ?></a>

				<ul class="header-cart-content">
					<?php if ( WC()->cart->get_cart_contents_count() > 0 ) : ?>
						<li class="desc"><?php echo sprintf( _n('%d item in the shopping cart', '%d items in the shopping cart', WC()->cart->get_cart_contents_count(), 'supernews'), WC()->cart->get_cart_contents_count() );?></li>
					<?php endif; ?>
					<?php if ( sizeof( WC()->cart->get_cart() ) > 0 ) : ?>
						<?php foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) : ?>
							<?php
							$_product     = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
							$product_id   = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );
							?>
							<?php
							if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_widget_cart_item_visible', true, $cart_item, $cart_item_key ) ) {

								$product_name  = apply_filters( 'woocommerce_cart_item_name', $_product->get_title(), $cart_item, $cart_item_key );
								$thumbnail     = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );
								$product_price = apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );

								?>
								<li class="clearfix">
									<a href="<?php echo esc_url( get_permalink( $product_id ) ); ?>">
										<?php echo str_replace( array( 'http:', 'https:' ), '', $thumbnail ); ?>
									</a>
									<a href="<?php echo esc_url( get_permalink( $product_id ) ); ?>" class="product-title"><?php echo esc_attr( $product_name ); ?></a>
									<span class="quantity"><?php printf( __( 'Unit Price: %s', 'supernews' ), $product_price ); ?></span>
									<span class="quantity"><?php printf( __( 'Quantity: %s', 'supernews' ), $cart_item['quantity'] ); ?></span>
									<a href="<?php echo esc_url( WC()->cart->get_remove_url( $cart_item_key ) ) ?>" class="product-remove"><?php _e( '&times;', 'supernews' ); ?></a>
								</li>
								<?php } ?>
							<?php endforeach; ?>
						<?php else : ?>
							<li class="empty"><?php _e( 'No products in the cart.', 'supernews' ); ?></li>
						<?php endif; ?>
						<?php if ( sizeof( WC()->cart->get_cart() ) > 0 ) : ?>
							<li class="clearfix">
								<p class="cart-total"><?php printf( __( 'Subtotal %s', 'supernews' ), '<strong class="amount">' . WC()->cart->get_cart_subtotal() . '</strong>' ); ?></p>
								<p>
									<form action="<?php echo esc_url( WC()->cart->get_cart_url() ); ?>">
										<button class="add_to_cart_button"><?php _e( 'View Shopping Cart', 'supernews' ); ?></button>
									</form>
									<form action="<?php echo esc_url( WC()->cart->get_checkout_url() ); ?>">
										<button class="button"><?php _e( 'Proceed to Checkout', 'supernews' ); ?></button>
									</form>
								</p>
							</li>
						<?php endif; ?>
					</ul>

			</li>
		</ul>
	</div>
	<?php
}
endif;

/**
 * Cart Fragments
 * Ensure cart contents update when products are added to the cart via AJAX
 *
 * @since  1.1.0
 */
function supernews_cart_link_fragment( $fragments ) {

	ob_start();

	supernews_header_cart();

	$fragments['div.header-cart'] = ob_get_clean();

	return $fragments;
}
if ( defined( 'WC_VERSION' ) && version_compare( WC_VERSION, '2.3', '>=' ) ) {
	add_filter( 'woocommerce_add_to_cart_fragments', 'supernews_cart_link_fragment' );
} else {
	add_filter( 'add_to_cart_fragments', 'supernews_cart_link_fragment' );
}
